@@ -56,10 +56,12 @@ void up_sanity_check (gleDouble up[3],	/* up vector for contour */
    VEC_DIFF (diff, point_array[1], point_array[0]);
    VEC_LENGTH (len, diff);
    if (len == 0.0) {
-      /* This error message should go through "official" error interface */
-/*
+      /* This error message should go through an "official" error interface */
+#ifndef WIN32
+      /* Win32 GUI programs do not have a valid error stream; and so 
+       * although they compile, they will crash when run. */
       fprintf (stderr, "Extrusion: Warning: initial segment zero length \n");
-*/
+#endif /* WIN32 */
 
       /* loop till we find something that ain't of zero length */
       for (i=1; i<npoints-2; i++) {
@@ -79,9 +81,13 @@ void up_sanity_check (gleDouble up[3],	/* up vector for contour */
 
    VEC_LENGTH (len, up);
    if (len == 0.0) {
-      /* This error message should go through "official" error interface */
-      fprintf (stderr, "Extrusion: Warning: ");
-      fprintf (stderr, "contour up vector parallel to tubing direction \n");
+      /* This error message should go through an "official" error interface */
+#ifndef WIN32
+      /* Win32 GUI programs do not have a valid error stream; and so 
+       * although they compile, they will crash when run. */
+      fprintf (stderr, "Extrusion: Warning: "
+               "contour up vector parallel to tubing direction \n");
+#endif /* WIN32 */
 
       /* do like the error message says ... */
       VEC_COPY (up, diff);
@@ -102,6 +108,10 @@ void draw_raw_style_end_cap (int ncp,		/* number of contour points */
 {
    int j;
 
+#ifdef GL_32
+   gleDouble point[3];
+#endif /* GL_32 */
+
 #ifdef OPENGL_10
    GLUtriangulatorObj *tobj;
    double *pts;
@@ -109,7 +119,7 @@ void draw_raw_style_end_cap (int ncp,		/* number of contour points */
 
 
 #ifdef GL_32
-   /* old-style gl handles concave polygons no problem, so the code is
+   /* Old-style gl handles concave polygons no problem, so the code is
     * simple.  New-style gl is a lot more tricky. */
    point [2] = zval;
    BGNPOLYGON ();
